@@ -572,6 +572,7 @@ type SearchResponse struct {
 	TotalPages         int64           `json:"totalPages,omitempty"`
 	FacetStats         json.RawMessage `json:"facetStats,omitempty"`
 	IndexUID           string          `json:"indexUid,omitempty"`
+	QueryVector        *[]float32      `json:"queryVector,omitempty"`
 }
 
 type MultiSearchResponse struct {
@@ -693,6 +694,7 @@ type ExperimentalFeaturesResult struct {
 
 type SwapIndexesParams struct {
 	Indexes []string `json:"indexes"`
+	Rename  bool     `json:"rename"`
 }
 
 // Health is the request body for set meilisearch health
@@ -700,9 +702,10 @@ type Health struct {
 	Status string `json:"status"`
 }
 
-// UpdateIndexRequest is the request body for update Index primary key
-type UpdateIndexRequest struct {
-	PrimaryKey string `json:"primaryKey"`
+// UpdateIndexRequest is the request body for update Index primary key and renaming IndexUid
+type UpdateIndexRequestParams struct {
+	PrimaryKey string `json:"primaryKey,omitempty"`
+	UID        string `json:"uid,omitempty"`
 }
 
 func (s *SearchRequest) validate() {
